@@ -1,22 +1,9 @@
-/*****************************************************************************
- * This file is part of KDevelop                                             *
- * Copyright 2010 Miquel Canes Gonzalez <miquelcanes@gmail.com>              *
- * Copyright 2011-2013 by Sven Brauch <svenbrauch@googlemail.com>            *
- *                                                                           *
- * This program is free software; you can redistribute it and/or             *
- * modify it under the terms of the GNU General Public License as            *
- * published by the Free Software Foundation; either version 2 of            *
- * the License, or (at your option) any later version.                       *
- *                                                                           *
- * This program is distributed in the hope that it will be useful,           *
- * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
- * GNU General Public License for more details.                              *
- *                                                                           *
- * You should have received a copy of the GNU General Public License         *
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.     *
- *****************************************************************************
- */
+/*
+    SPDX-FileCopyrightText: 2010 Miquel Canes Gonzalez <miquelcanes@gmail.com>
+    SPDX-FileCopyrightText: 2011-2013 Sven Brauch <svenbrauch@googlemail.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "expressionvisitor.h"
 #include "types/nonetype.h"
@@ -365,7 +352,7 @@ void ExpressionVisitor::visitSubscript(SubscriptAst* node)
                 continue;
             }
         }
-        if ( (node->slice->astType != Ast::IndexAstType) && type.cast<ListType>() ) {
+        if ( (node->slice->astType == Ast::SliceAstType) && type.cast<ListType>() ) {
             if ( type.cast<MapType>() ) {
                 continue; // Can't slice dicts.
             }
@@ -373,7 +360,7 @@ void ExpressionVisitor::visitSubscript(SubscriptAst* node)
             result = Helper::mergeTypes(result, type);
         }
         else if ( const auto& indexed = type.cast<IndexedContainer>() ) {
-            long sliceIndex = integerValue(static_cast<IndexAst*>(node->slice)->value, indexed->typesCount());
+            long sliceIndex = integerValue(node->slice, indexed->typesCount());
             if ( 0 <= sliceIndex && sliceIndex < indexed->typesCount() ) {
                 result = Helper::mergeTypes(result, indexed->typeAt(sliceIndex).abstractType());
                 continue;
